@@ -1,24 +1,33 @@
 import os
 from collections import defaultdict
+from datetime import datetime
+from functools import partial
 from math import ceil, log10
 from types import MethodType
 from typing import Optional, Sequence, Union
 
 import numpy as np
-from napari.layers import Image, Points, Shapes
+from napari.layers import Image, Points, Shapes, Tracks
 from napari.layers.points._points_key_bindings import register_points_action
 from napari.layers.utils import color_manager
 from napari.utils.events import Event
 from napari.utils.history import get_save_history, update_save_history
+from napari._qt.widgets.qt_welcome import QtWelcomeLabel
+from qtpy.QtCore import Qt, QTimer, Signal
+from qtpy.QtGui import QPainter
 from qtpy.QtWidgets import (
     QButtonGroup,
+    QCheckBox,
     QComboBox,
     QFileDialog,
     QGroupBox,
     QHBoxLayout,
+    QLabel,
     QMessageBox,
     QPushButton,
     QRadioButton,
+    QStyle,
+    QStyleOption,
     QVBoxLayout,
     QWidget,
 )
@@ -26,7 +35,7 @@ from qtpy.QtWidgets import (
 from napari_deeplabcut import keypoints
 from napari_deeplabcut._reader import _load_config
 from napari_deeplabcut._writer import _write_config, _write_image
-from napari_deeplabcut.misc import to_os_dir_sep
+from napari_deeplabcut.misc import encode_categories, to_os_dir_sep
 
 
 def _get_and_try_preferred_reader(
@@ -92,11 +101,33 @@ def _save_layers_dialog(self, selected=False):
         )
         if filename:
             self.viewer.layers.save(filename, selected=selected)
+        else:
+            return
+    self._is_saved = True
+    self.last_saved_label.setText(
+        f'Last saved at {str(datetime.now().time()).split(".")[0]}'
+    )
+    self.last_saved_label.show()
+
+
+def on_close(self, event, widget):
+    if widget._stores and not widget._is_saved:
+        QMessageBox.warning(
+            widget,
+            "",
+            "Please save your data before closing",
+            QMessageBox.Ok,
+        )
+        event.ignore()
+    else:
+        event.accept()
 
 
 class KeypointControls(QWidget):
     def __init__(self, napari_viewer):
         super().__init__()
+        self._is_saved = False
+
         self.viewer = napari_viewer
         self.viewer.layers.events.inserted.connect(self.on_insert)
         self.viewer.layers.events.removed.connect(self.on_remove)
@@ -106,10 +137,30 @@ class KeypointControls(QWidget):
             self.viewer.window.qt_viewer,
         )
 
+        status_bar = self.viewer.window._qt_window.statusBar()
+        self.last_saved_label = QLabel('')
+        self.last_saved_label.hide()
+        status_bar.insertPermanentWidget(0, self.last_saved_label)
+
+        # Hack napari's Welcome overlay to show more relevant instructions
+        overlay = self.viewer.window._qt_viewer._canvas_overlay
+        welcome_widget = overlay.layout().itemAt(1).widget()
+        welcome_widget.deleteLater()
+        w = QtWelcomeWidget(None)
+        overlay._overlay = w
+        overlay.addWidget(w)
+        overlay._overlay.sig_dropped.connect(overlay.sig_dropped)
+
         self._label_mode = keypoints.LabelMode.default()
 
         # Hold references to the KeypointStores
         self._stores = {}
+        # Intercept close event if data were not saved
+        self.viewer.window._qt_window.closeEvent = partial(
+            on_close,
+            self.viewer.window._qt_window,
+            widget=self,
+        )
 
         # Storage for extra image metadata that are relevant to other layers.
         # These are updated anytime images are added to the Viewer
@@ -121,6 +172,19 @@ class KeypointControls(QWidget):
         self._menus = []
 
         self._video_group = self._form_video_action_menu()
+
+        vlayout = QHBoxLayout()
+        trail_label = QLabel("Show trails")
+        self._trail_cb = QCheckBox()
+        self._trail_cb.setToolTip("toggle trails visibility")
+        self._trail_cb.setChecked(False)
+        self._trail_cb.setEnabled(False)
+        self._trail_cb.stateChanged.connect(self._show_trails)
+        self._trails = None
+        vlayout.addWidget(trail_label)
+        vlayout.addWidget(self._trail_cb)
+        self._layout.addLayout(vlayout)
+
         self._radio_group = self._form_mode_radio_buttons()
 
         # Substitute default menu action with custom one
@@ -129,12 +193,35 @@ class KeypointControls(QWidget):
                 action.triggered.disconnect()
                 action.triggered.connect(
                     lambda: _save_layers_dialog(
-                        self.viewer.window.qt_viewer,
+                        self,
                         selected=True,
                     )
                 )
                 break
 
+    def _move_image_layer_to_bottom(self, index):
+        if (ind := index) != 0:
+            self.viewer.layers.move_selected(ind, 0)
+            self.viewer.layers.select_next()  # Auto-select the Points layer
+
+    def _show_trails(self, state):
+        if state == Qt.Checked:
+            if self._trails is None:
+                store = list(self._stores.values())[0]
+                inds = encode_categories(store.layer.properties["label"])
+                temp = np.c_[inds, store.layer.data]
+                self._trails = self.viewer.add_tracks(
+                    temp,
+                    tail_length=50,
+                    head_length=50,
+                    tail_width=6,
+                    name="trails",
+                    colormap="viridis",
+                )
+            self._trails.visible = True
+        else:
+            self._trails.visible = False
+
     def _form_video_action_menu(self):
         group_box = QGroupBox("Video")
         layout = QVBoxLayout()
@@ -266,15 +353,10 @@ class KeypointControls(QWidget):
                     "name": layer.name,
                 }
             )
-            # FIXME Ensure the images are always underneath the other layers
-            # self.viewer.layers.selection = []
-            # if (ind := event.index) != 0:
-            #     order = list(range(len(self.viewer.layers)))
-            #     order.remove(ind)
-            #     new_order = [ind] + order
-            #     self.viewer.layers.move_multiple(new_order)
-            # if (ind := event.index) != 0:
-            #     self.viewer.layers.move_selected(ind, 0)
+            # Delay layer sorting
+            QTimer.singleShot(
+                10, partial(self._move_image_layer_to_bottom, event.index)
+            )
         elif isinstance(layer, Points):
             store = keypoints.KeypointStore(self.viewer, layer)
             self._stores[layer] = store
@@ -304,6 +386,7 @@ class KeypointControls(QWidget):
                     "project": layer.metadata.get("project"),
                 }
             )
+            self._trail_cb.setEnabled(True)
         for layer_ in self.viewer.layers:
             if not isinstance(layer_, Image):
                 self._remap_frame_indices(layer_)
@@ -317,12 +400,17 @@ class KeypointControls(QWidget):
                 self._layout.removeWidget(menu)
                 menu.setParent(None)
                 menu.destroy()
+            self._trail_cb.setEnabled(False)
+            self.last_saved_label.hide()
         elif isinstance(layer, Image):
             self._images_meta = dict()
             paths = layer.metadata.get("paths")
             if paths is None:
                 for widget in self._video_group:
                     widget.setEnabled(False)
+        elif isinstance(layer, Tracks):
+            self._trail_cb.setChecked(False)
+            self._trails = None
 
     @register_points_action("Change labeling mode")
     def cycle_through_label_modes(self, *args):
@@ -434,3 +522,113 @@ def create_dropdown_menu(store, items, attr):
 
     menu.currentIndexChanged.connect(item_changed)
     return menu
+
+
+# WelcomeWidget modified from:
+# https://github.com/napari/napari/blob/a72d512972a274380645dae16b9aa93de38c3ba2/napari/_qt/widgets/qt_welcome.py#L28
+class QtWelcomeWidget(QWidget):
+    """Welcome widget to display initial information and shortcuts to user."""
+
+    sig_dropped = Signal("QEvent")
+
+    def __init__(self, parent):
+        super().__init__(parent)
+
+        # Create colored icon using theme
+        self._image = QLabel()
+        self._image.setObjectName("logo_silhouette")
+        self._image.setMinimumSize(300, 300)
+        self._label = QtWelcomeLabel(
+            """
+            Drop a folder from within a DeepLabCut's labeled-data directory,
+            and,  if labeling from scratch,
+            the corresponding project's config.yaml file.
+            """
+        )
+
+        # Widget setup
+        self.setAutoFillBackground(True)
+        self.setAcceptDrops(True)
+        self._image.setAlignment(Qt.AlignCenter)
+        self._label.setAlignment(Qt.AlignCenter)
+
+        # Layout
+        text_layout = QVBoxLayout()
+        text_layout.addWidget(self._label)
+
+        layout = QVBoxLayout()
+        layout.addStretch()
+        layout.setSpacing(30)
+        layout.addWidget(self._image)
+        layout.addLayout(text_layout)
+        layout.addStretch()
+
+        self.setLayout(layout)
+
+    def paintEvent(self, event):
+        """Override Qt method.
+
+        Parameters
+        ----------
+        event : qtpy.QtCore.QEvent
+            Event from the Qt context.
+        """
+        option = QStyleOption()
+        option.initFrom(self)
+        p = QPainter(self)
+        self.style().drawPrimitive(QStyle.PE_Widget, option, p, self)
+
+    def _update_property(self, prop, value):
+        """Update properties of widget to update style.
+
+        Parameters
+        ----------
+        prop : str
+            Property name to update.
+        value : bool
+            Property value to update.
+        """
+        self.setProperty(prop, value)
+        self.style().unpolish(self)
+        self.style().polish(self)
+
+    def dragEnterEvent(self, event):
+        """Override Qt method.
+
+        Provide style updates on event.
+
+        Parameters
+        ----------
+        event : qtpy.QtCore.QEvent
+            Event from the Qt context.
+        """
+        self._update_property("drag", True)
+        if event.mimeData().hasUrls():
+            event.accept()
+        else:
+            event.ignore()
+
+    def dragLeaveEvent(self, event):
+        """Override Qt method.
+
+        Provide style updates on event.
+
+        Parameters
+        ----------
+        event : qtpy.QtCore.QEvent
+            Event from the Qt context.
+        """
+        self._update_property("drag", False)
+
+    def dropEvent(self, event):
+        """Override Qt method.
+
+        Provide style updates on event and emit the drop event.
+
+        Parameters
+        ----------
+        event : qtpy.QtCore.QEvent
+            Event from the Qt context.
+        """
+        self._update_property("drag", False)
+        self.sig_dropped.emit(event)
