@@ -2,6 +2,7 @@ import os
 from itertools import groupby
 
 import pandas as pd
+import yaml
 from napari.layers import Shapes
 from napari.plugins._builtins import napari_write_shapes
 from skimage.io import imsave
@@ -11,6 +12,11 @@ from napari_deeplabcut import misc
 from napari_deeplabcut._reader import _load_config
 
 
+def _write_config(config_path: str, params: dict):
+    with open(config_path, "w") as file:
+        yaml.safe_dump(params, file)
+
+
 def write_hdf(filename, data, metadata):
     file, _ = os.path.splitext(filename)  # FIXME Unused currently
     temp = pd.DataFrame(data[:, -1:0:-1], columns=["x", "y"])
@@ -35,7 +41,7 @@ def write_hdf(filename, data, metadata):
         df.index = [meta["paths"][i] for i in df.index]
     misc.guarantee_multiindex_rows(df)
 
-    name = metadata["name"]
+    name = meta["name"]
     root = meta["root"]
     if "machine" in name:  # We are attempting to save refined model predictions
         df.drop("likelihood", axis=1, level="coords", inplace=True, errors="ignore")
@@ -69,6 +75,15 @@ def write_hdf(filename, data, metadata):
     return filename
 
 
+def _write_image(data, output_path, plugin=None):
+    imsave(
+        output_path,
+        img_as_ubyte(data).squeeze(),
+        plugin=plugin,
+        check_contrast=False,
+    )
+
+
 def write_masks(foldername, data, metadata):
     folder, _ = os.path.splitext(foldername)
     os.makedirs(folder, exist_ok=True)
@@ -83,6 +98,6 @@ def write_masks(foldername, data, metadata):
     for n, mask in enumerate(masks):
         image_name = os.path.basename(meta["paths"][frame_inds[n]])
         output_path = filename.format(os.path.splitext(image_name)[0], shape_inds[n])
-        imsave(output_path, img_as_ubyte(mask).squeeze(), check_contrast=False)
+        _write_image(mask, output_path)
     napari_write_shapes(os.path.join(folder, "vertices.csv"), data, metadata)
     return folder
